[SeesawLoss](https://arxiv.org/abs/2008.10032) implementation using PyTorch

### Install

```bash
pip install seesawloss
```

### Usage

```python
from seesawloss import SeesawLoss

...
criterion = SeesawLoss(num_classes=1000)
...
```
